@@ -47,7 +47,7 @@ inversion_defaults = {
     "gy_channel": None,
     "gy_uncertainty": 1.0,
     "starting_model_object": None,
-    "starting_model": None,
+    "starting_model": 1e-4,
     "tile_spatial": 1,
     "output_tile_files": False,
     "z_from_topo": False,
@@ -66,7 +66,7 @@ inversion_defaults = {
     "u_cell_size": 25.0,
     "v_cell_size": 25.0,
     "w_cell_size": 25.0,
-    "octree_levels_topo": [16, 8, 4, 2],
+    "octree_levels_topo": [0, 0, 4, 4],
     "octree_levels_obs": [4, 4, 4, 4],
     "depth_core": 500.0,
     "max_distance": 5000.0,
@@ -533,7 +533,7 @@ default_ui_json = {
         "dataType": "Float",
         "group": "Starting Model",
         "main": True,
-        "isValue": False,
+        "isValue": True,
         "parent": "starting_model_object",
         "label": "Density (g/cc)",
         "property": None,
