@@ -49,7 +49,7 @@ inversion_defaults = {
     "bz_channel": None,
     "bz_uncertainty": 1.0,
     "starting_model_object": None,
-    "starting_model": None,
+    "starting_model": 1e-4,
     "tile_spatial": 1,
     "output_tile_files": False,
     "z_from_topo": False,
@@ -68,7 +68,7 @@ inversion_defaults = {
     "u_cell_size": 25.0,
     "v_cell_size": 25.0,
     "w_cell_size": 25.0,
-    "octree_levels_topo": [16, 8, 4, 2],
+    "octree_levels_topo": [0, 0, 4, 4],
     "octree_levels_obs": [4, 4, 4, 4],
     "depth_core": 500.0,
     "max_distance": 5000.0,
@@ -241,14 +241,14 @@ default_ui_json = {
         "value": 50000.0,
     },
     "inducing_field_inclination": {
-        "min": 0.0,
+        "min": -90.0,
+        "max": 90.0,
         "main": True,
         "group": "Inducing Field",
         "label": "Inclination",
         "value": 90.0,
     },
     "inducing_field_declination": {
-        "min": 0.0,
         "main": True,
         "group": "Inducing Field",
         "label": "Declination",
@@ -559,11 +559,11 @@ default_ui_json = {
         "dataType": "Float",
         "group": "Starting Model",
         "main": True,
-        "isValue": False,
+        "isValue": True,
         "parent": "starting_model_object",
         "label": "Susceptibility (SI)",
         "property": None,
-        "value": 0.0,
+        "value": 1e-4,
     },
     "out_group": {"label": "Results group name", "value": "SusceptibilityInversion"},
 }
