@@ -1,9 +1,9 @@
-#  Copyright (c) 2021 Mira Geoscience Ltd.
+#  Copyright (c) 2022 Mira Geoscience Ltd.
 #
 #  This file is part of geoapps.
 #
 #  geoapps is distributed under the terms and conditions of the MIT License
 #  (see LICENSE file at the root of this source code package).
 
-from .constants import default_ui_json
+from .constants import app_initializer, default_ui_json
 from .params import MagneticVectorParams
