@@ -51,7 +51,7 @@ inversion_defaults = {
     "starting_model_object": None,
     "starting_inclination_object": None,
     "starting_declination_object": None,
-    "starting_model": None,
+    "starting_model": 1e-4,
     "starting_inclination": None,
     "starting_declination": None,
     "tile_spatial": 1,
@@ -72,7 +72,7 @@ inversion_defaults = {
     "u_cell_size": 25.0,
     "v_cell_size": 25.0,
     "w_cell_size": 25.0,
-    "octree_levels_topo": [16, 8, 4, 2],
+    "octree_levels_topo": [0, 0, 4, 4],
     "octree_levels_obs": [4, 4, 4, 4],
     "depth_core": 500.0,
     "max_distance": 5000.0,
@@ -254,14 +254,14 @@ default_ui_json = {
         "value": 50000.0,
     },
     "inducing_field_inclination": {
-        "min": 0.0,
+        "min": -90.0,
+        "max": 90.0,
         "main": True,
         "group": "Inducing Field",
         "label": "Inclination",
         "value": 90.0,
     },
     "inducing_field_declination": {
-        "min": 0.0,
         "main": True,
         "group": "Inducing Field",
         "label": "Declination",
@@ -600,11 +600,11 @@ default_ui_json = {
         "dataType": "Float",
         "group": "Starting Model",
         "main": True,
-        "isValue": False,
+        "isValue": True,
         "parent": "starting_model_object",
         "label": "Susceptibility (SI)",
         "property": None,
-        "value": 0.0,
+        "value": 1e-4,
     },
     "starting_inclination": {
         "association": ["Cell", "Vertex"],
@@ -662,7 +662,7 @@ default_ui_json = {
         "association": ["Cell", "Vertex"],
         "dataType": "Float",
         "group": "Regularization",
-        "isValue": False,
+        "isValue": True,
         "optional": True,
         "enabled": False,
         "label": "Reference inclination value",
@@ -674,7 +674,7 @@ default_ui_json = {
         "association": ["Cell", "Vertex"],
         "dataType": "Float",
         "group": "Regularization",
-        "isValue": False,
+        "isValue": True,
         "optional": True,
         "enabled": False,
         "label": "Reference declination value",
