@@ -1,4 +1,4 @@
-#  Copyright (c) 2021 Mira Geoscience Ltd.
+#  Copyright (c) 2022 Mira Geoscience Ltd.
 #
 #  This file is part of geoapps.
 #
@@ -9,13 +9,18 @@ from __future__ import annotations
 
 from copy import deepcopy
 from typing import Any
-from uuid import UUID
 
 from geoh5py.shared import Entity
 
 from ..params import Params
 from ..validators import InputFreeformValidator
-from .constants import default_ui_json, defaults, required_parameters, validations
+from .constants import (
+    default_ui_json,
+    defaults,
+    free_format_dict,
+    required_parameters,
+    validations,
+)
 
 
 class PeakFinderParams(Params):
@@ -74,12 +79,12 @@ class PeakFinderParams(Params):
 
         # Validate.
         if self.validate:
-            self.workspace = params_dict["geoh5"]
+            self.geoh5 = params_dict["geoh5"]
             self.associations = self.get_associations(params_dict)
             self.validator: InputFreeformValidator = InputFreeformValidator(
                 required_parameters,
                 validations,
-                self.workspace,
+                self.geoh5,
                 free_params_keys=self._free_param_keys,
             )
             self.validator.validate_chunk(params_dict, self.associations)
@@ -121,9 +126,7 @@ class PeakFinderParams(Params):
 
     @data.setter
     def data(self, val):
-        self.setter_validator(
-            "data", val, fun=lambda x: UUID(x) if isinstance(val, str) else x
-        )
+        self.setter_validator("data", val, fun=self._uuid_promoter)
 
     @property
     def flip_sign(self):
@@ -155,9 +158,7 @@ class PeakFinderParams(Params):
 
     @line_field.setter
     def line_field(self, val):
-        self.setter_validator(
-            "line_field", val, fun=lambda x: UUID(x) if isinstance(val, str) else x
-        )
+        self.setter_validator("line_field", val, fun=self._uuid_promoter)
 
     @property
     def line_id(self):
@@ -221,9 +222,7 @@ class PeakFinderParams(Params):
 
     @objects.setter
     def objects(self, val):
-        self.setter_validator(
-            "objects", val, fun=lambda x: UUID(x) if isinstance(val, str) else x
-        )
+        self.setter_validator("objects", val, fun=self._uuid_promoter)
 
     @property
     def plot_result(self):
@@ -320,22 +319,16 @@ class PeakFinderParams(Params):
 
         if "geoh5" in params_dict.keys():
             if params_dict["geoh5"] is not None:
-                setattr(self, "workspace", params_dict["geoh5"])
+                setattr(self, "geoh5", params_dict["geoh5"])
 
         free_param_dict = {}
         for key, value in params_dict.items():
 
-            if key == "workspace":
-                continue  # ignores deprecated workspace name
-
             if "Template" in key:
                 continue
 
             # Update default_ui_json and store free_param_groups for app
-            if (
-                self._free_param_identifier in key.lower()
-                and key not in self.default_ui_json
-            ):
+            if self._free_param_identifier in key.lower():
                 for param in self._free_param_keys:
                     if param in key.lower():
                         group = key.lower().replace(param, "").rstrip()
@@ -346,7 +339,7 @@ class PeakFinderParams(Params):
 
                         free_param_dict[group][param] = value
                         self.default_ui_json[key] = deepcopy(
-                            default_ui_json[f"Template {param.capitalize()}"]
+                            free_format_dict[f"Template {param.capitalize()}"]
                         )
                         self.default_ui_json[key]["group"] = group.capitalize()
                         break
@@ -363,10 +356,5 @@ class PeakFinderParams(Params):
                 else:
                     setattr(self, key, value)
 
-        # Clear Template
-        for key in list(self.default_ui_json.keys()):
-            if "Template" in key:
-                del self.default_ui_json[key]
-
         self._free_param_dict = free_param_dict
         self.param_names = list(self.default_ui_json.keys())
