@@ -15,6 +15,7 @@ from geoapps.drivers.direct_current_inversion import DirectCurrentParams
 from geoapps.drivers.induced_polarization_inversion import InducedPolarizationParams
 from geoapps.drivers.magnetic_vector_inversion import MagneticVectorParams
 from geoapps.inversion.dcip_inversion_app import InversionApp as DCInversionApp
+from geoapps.inversion.em1d_inversion_app import InversionApp as EM1DInverionApp
 from geoapps.inversion.pf_inversion_app import InversionApp as MagInversionApp
 from geoapps.io import InputFile
 
@@ -274,3 +275,28 @@ def test_ip_inversion(tmp_path):
             assert (
                 getattr(app, "_" + group + "_group").options.value == "Model"
             ), f"Property group {group} did not reset to 'Model'"
+
+
+def test_em1d_inversion(tmp_path):
+    """Tests the jupyter application for em1d inversion."""
+    ws = Workspace(project)
+    new_geoh5 = Workspace(path.join(tmp_path, "invtest.geoh5"))
+    new_obj = ws.get_entity(UUID("{bb208abb-dc1f-4820-9ea9-b8883e5ff2c6}"))[0].copy(
+        parent=new_geoh5
+    )
+    changes = {
+        "objects": new_obj.uid,
+        "data": (UUID("{b834a590-dea9-48cb-abe3-8c714bb0bb7c}"),),
+    }
+    side_effects = {"system": "VTEM (2007)"}
+    app = EM1DInverionApp(geoh5=project, plot_result=False)
+    app.geoh5 = new_geoh5
+
+    for param, value in changes.items():
+        if isinstance(getattr(app, param), Widget):
+            getattr(app, param).value = value
+        else:
+            setattr(app, param, value)
+
+    for key, value in side_effects.items():
+        assert getattr(app, key).value == value, f"Failed to change {key} with {value}."
