@@ -1,4 +1,4 @@
-#  Copyright (c) 2021 Mira Geoscience Ltd.
+#  Copyright (c) 2022 Mira Geoscience Ltd.
 #
 #  This file is part of geoapps.
 #
@@ -15,14 +15,14 @@ from geoapps.drivers.components import InversionWindow
 from geoapps.io.Gravity import GravityParams, default_ui_json
 from geoapps.utils.testing import Geoh5Tester
 
-workspace = Workspace("./FlinFlon.geoh5")
+geoh5 = Workspace("./FlinFlon.geoh5")
 
 
 def test_initialize(tmp_path):
 
     # Test initialize from params
     tester = Geoh5Tester(
-        workspace,
+        geoh5,
         tmp_path,
         "test.geoh5",
         ui=deepcopy(default_ui_json),
